% Solves the wave equation u_t + c*u_x = 0.
function u = wave_lax_wendroff(c, u0, x, n_iter, deltat)
    N = size(x,2);
    deltax = (x(N) - x(1))/(N-1);
    sigma = c*deltat/deltax;
    hsigma = 0.5*sigma;
    hsigma2 = 0.5*sigma*sigma;

    u = zeros(n_iter, N);
    u(1,:) = u0;
    
    j = 2:N-1;
    for n = 2:n_iter
        u(n,1) = u0(1); % Boundary condition.
        uo = u(n-1, :);
        u(n,j) = uo(j) - hsigma*(uo(j+1) - uo(j-1)) + ...
                 hsigma2*( uo(j+1) - 2*uo(j) + uo(j-1) );
        u(n,N) = u0(N);  % Boundary condition.
    end
end
